# vim: set sw=4 ts=4 et nu:
#
# spec file for package etckeeper
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2014 Mitsutoshi NAKANO <bkbin005@rinku.zaq.ne.jp>
# Copyright (c) 2013 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# see https://en.opensuse.org/openSUSE:Packaging_Python#Compatibility_with_older_distributions
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}
Name:           etckeeper
Version:        1.13
Release:        5.4
Summary:        Store /etc under Version Control
License:        GPL-2.0+
Group:          System/Management
Source:         http://ftp.debian.org/debian/pool/main/e/etckeeper/%{name}_%{version}.tar.gz
Source99:       %{name}-rpmlintrc
# PATCH-FIX-UPSTREAM etckeeper-avoid-packagelist.patch gh#joeyh/etckeeper#17 bkbin005@rinku.zaq.ne.jp -- add AVOID_PACKAGELIST
Patch0:         etckeeper-avoid-packagelist.patch
Url:            http://joeyh.name/code/etckeeper/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%define LPM rpm
BuildRequires:  make
# added for bzr 2014-07-10 bkbin005@rinku.zaq.ne.jp
BuildRequires:  bzr
BuildRequires:  python-devel

%if 0%{?suse_version}
# modified 2014-07-09 bkbin005@rinku.zaq.ne.jp
# Users should be able to select VCS.
Recommends:     git
Recommends:     %{name}-cron = %{version}-%{release}
Recommends:     %{name}-zypp-plugin = %{version}-%{release}
BuildRequires:  libzypp
%define HPM zypper
%else
BuildRequires:  yum
Requires:       %{name}-cron = %{version}-%{release}
Requires:       %{name}-yum-plugin = %{version}-%{release}
%define HPM yum
%endif

%description
The etckeeper program is a tool to let /etc be stored in a git,
mercurial, bzr or darcs repository. It hooks into yum to automatically
commit changes made to /etc during package upgrades. It tracks file
metadata that version control systems do not normally support, but that
is important for /etc, such as the permissions of /etc/shadow. It is
quite modular and configurable, while also being simple to use if you
understand the basics of working with version control.


%package cron
Summary:        The etckeeper cron function
Group:          System/Management
Requires:       etckeeper = %{version}-%{release}
Provides:       etckeeper:%{_sysconfdir}/cron.daily/etckeeper
%if 0%{?suse_version}
Requires:       cron
%else
Requires:       crontabs
%endif

%description cron
The etckeeper-cron calls etckeeper from cron.


%if 0%{?suse_version}
%package zypp-plugin
Summary:        The etckeeper integration function with ZYpp
Group:          System/Management
Requires:       etckeeper = %{version}-%{release}
Requires:       zypp-plugin-python
BuildRequires:  zypp-plugin-python
Obsoletes:      etckeeper-pkgmanager-collabo < %{version}-%{release}
Provides:       etckeeper-pkgmanager-collabo = %{version}-%{release}
Provides:       etckeeper:%{_prefix}/lib/zypp/plugins/commit/zypper-etckeeper.py

%description zypp-plugin
The etckeeper-zypp-plugin calls etckeeper from ZYpp.
%else
%package yum-plugin
Summary:        The etckeeper integration function with YUM
Group:          System/Management
Requires:       etckeeper = %{version}-%{release}
Obsoletes:      etckeeper-pkgmanager-collabo
Provides:       etckeeper-pkgmanager-collabo = %{version}-%{release}
Provides:       etckeeper:%{_sysconfdir}/yum/pluginconf.d/etckeeper.conf

%description yum-plugin
The etckeeper-zypp-plugin calls etckeeper from YUM.
%endif

%prep
%setup -q -n "%{name}"
%patch0 -p1

%__perl -pi -e '
s|^(\s*)(HIGHLEVEL_PACKAGE_MANAGER)=.+|$1$2=%{HPM}|;
s|^(\s*)(LOWLEVEL_PACKAGE_MANAGER)=.+|$1$2=%{LPM}|;
s|^(\s*)(VCS)=.+|$1$2=git|;
' ./etckeeper.conf

%build
make %{?_smp_mflags}

%install
make \
    DESTDIR="%{buildroot}" \
    PYTHON_INSTALL_OPTS="--prefix=%{_prefix} --install-purelib=%{python_sitearch}" \
    install
install -D debian/cron.daily "%{buildroot}/etc/cron.daily/%{name}"

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%files
%defattr(-,root,root)
%doc GPL README.md TODO
%{_bindir}/etckeeper
%dir %{_sysconfdir}/etckeeper
%config(noreplace) %{_sysconfdir}/etckeeper/etckeeper.conf
%dir %{_sysconfdir}/etckeeper/*.d
%config %{_sysconfdir}/etckeeper/*.d/*
%doc %{_mandir}/man8/etckeeper.8*
%config %{_sysconfdir}/bash_completion.d/etckeeper
%{python_sitearch}/bzrlib/plugins/%{name}/
%{python_sitearch}/bzr_%{name}-*.egg-info

%files cron
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/cron.daily/etckeeper

%if 0%{?suse_version}
%files zypp-plugin
%defattr(-,root,root)
%{_prefix}/lib/zypp/plugins/commit/zypper-etckeeper.py
%else
%files yum-plugin
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/yum/pluginconf.d/etckeeper.conf
%{_prefix}/lib/yum-plugins/etckeeper.*
%endif

%changelog
* Mon Aug 18 2014 bkbin005@rinku.zaq.ne.jp
- renamed to etckeeper-rpmlintrc from etckeeper.rpmlintrc:
  To follow the packaging guidelines.
  Please see also:
  https://build.opensuse.org/request/show/244964#request_history
  http://lists.opensuse.org/opensuse-packaging/2007-07/msg00000.html
* Fri Aug 15 2014 bkbin005@rinku.zaq.ne.jp
- updated Source to 1.13:
  + Ignore check-mk-agent-logwatch's FHS violating
    /etc/check_mk/logwatch.state. Closes: deb#753903
  + Only allow [-a-z_] in etckeeper commands to avoid any possible
    directory traversal etc issues.
  + update-ignore, uninit: Fix parsing of ignore files containing '\'
- added etckeeper-avoid-packagelist.patch:
  Because it is slow that some package manager make the packagelist
  (eg, rpm -qa), high-level package manager might time out
  (eg. zypper in/remove).
  So I added this patch.
  If you think that the packagelist is unnecessary,
  set AVOID_PACKAGELIST=1 in etckeeper.conf.
  Or if you want to avoid it temporarily,
  you can use environment variable ETCKEEPER_AVOID_PACKAGELIST=1 .
  (eg, ETCKEEPER_AVOID_PACKAGELIST=1 zypper update).
  This patch was sent to upstream, but Joey does not accept it yet.
  Please see also gh#joeyh/etckeeper#17 .
- rename subpackage from pkgmanager-collabo
  to zypp-plugin or yum-plugin.
  please see also:
  http://lists.opensuse.org/archive/opensuse-factory/2014-07/msg00060.html
- added "Provides:" for renaming:
  pkgmanager-collabo => (zypp|yum)-plugin.
  Please see also:
  https://en.opensuse.org/openSUSE:Package_dependencies#Renaming_a_packageage
- added "Provides:" for split packages: etekeeper-cron and plugins.
  Please see also:
  https://en.opensuse.org/openSUSE:Package_dependencies#Splitting_off_a_sub-pack
- added "Reccomends: git".
  please see also:
  http://lists.opensuse.org/archive/opensuse-factory/2014-07/msg00060.html
- added bzr support files.
  Their files need "Buildrequires: python-devel bzr",
  but did not write them, so they were not installed untill now.
- added Python Compatibility with older distributions codes.
  Please see also:
  https://en.opensuse.org/openSUSE:Packaging_Python#Compatibility_with_older_distributions
- added version-release number to Recommendes and Requires.
  It is desirable that etckeeper packages are same version.
- removed lib/zypp directories:
  They should belong libzypp.
  + remove them.
  + added "BuildRequire: zypp-plugin-python".
* Mon Jul  7 2014 bkbin005@rinku.zaq.ne.jp
- modified etckeeper.spec style
  by "osc service run format_spec_file".
- removed lint code 'rm -rf "%%{buildroot}%%{_prefix}/lib"/python*'.
  This line does not work.
- removed "Requires: git".
  users can select VCS.
- divide etckeeper package into 3.
  + etckeeper:
    main function.
  + etckeeper-cron:
    cron function.
  + etckeeper-pkgmanager-collabo:
    collaboration with package manager.
- fix (bnc#884154): forgot to reqire zypp-plugin-python.
* Wed Jul  2 2014 bkbin005@rinku.zaq.ne.jp
- fix (bnc#884154).  change permission and locale.
  + added etckeeper-zypp.patch
    1) changed zypper-etckeeper.py 's permission from 644 to 755
    (in Makefile).
    2) in zypper-etckeeper.py set LANG to C.
  please see also:
  http://lists.opensuse.org/archive/opensuse-factory/2014-06/msg00090.html
- version up to 1.12 from 1.7
  + README's filename changed from README to README.md.
  + fix some bugs.
  + fix some typos.
  for detail,
  please do "git clone git://git.kitenet.net/etckeeper.git"
  and "git log".
* Wed Aug 21 2013 dvaleev@suse.com
- don't require git to build
- relax git version requirement
* Sat Aug 10 2013 pascal.bleser@opensuse.org
- initial version (1.7)
